@@ -181,6 +181,8 @@ class RenderGroup:
 
 
 def render_group(fit: bool = False) -> Callable:
+    """A decorator that turns an iterable of renderables in to a group."""
+
     def decorator(method):
         """Convert a method that returns an iterable of renderables in to a RenderGroup."""
 
@@ -735,7 +737,7 @@ class Console:
         """Combined a number of renderables and text in to one renderable.
 
         Args:
-            renderables (Iterable[Union[str, ConsoleRenderable]]): Anyting that Rich can render.
+            renderables (Iterable[Union[str, ConsoleRenderable]]): Anything that Rich can render.
             sep (str, optional): String to write between print data. Defaults to " ".
             end (str, optional): String to write at end of print data. Defaults to "\\n".
             justify (str, optional): One of "left", "right", "center", or "full". Defaults to ``None``.
